@@ -32,14 +32,13 @@ class JSON2EDCLineageFiles:
         self.excel_file = None
         self.resource_items = None
         self.get_settings(configuration_file=configuration_file)
+        makedirs(self.output_directory, exist_ok=True)
 
     def process_files(self, excelfile=None):
         module = __name__ + "." + currentframe().f_code.co_name
         if excelfile is not None:
             self.excel_file = excelfile
             self.json_directory += excelfile + "/"
-            self.output_directory += excelfile + "/"
-            makedirs(self.output_directory, exist_ok=True)
 
         print("JSON directory:", self.json_directory)
         print("Output directory:", self.output_directory)
@@ -76,10 +75,12 @@ class JSON2EDCLineageFiles:
                 data = json.load(config)
                 self.schema_directory = data["schema_directory"]
                 self.json_directory = data["json_directory"]
-                self.output_directory = data["output_directory"]
+                if "output_directory" in data:
+                    self.output_directory = path.join(data["output_directory"], self.start_time_formatted)
+                else:
+                    self.output_directory = path.join(self.output_directory, self.start_time_formatted)
                 if self.excel_file is not None:
-                    self.json_directory += self.json_directory + self.excel_file + "/"
-                    self.output_directory += self.output_directory + self.excel_file + "/"
+                    self.json_directory = path.join(self.json_directory, self.excel_file)
                 self.resource_items = data["resource_items"]
                 # print("resource_items:", self.resource_items)
         except FileNotFoundError or IOError as e:
@@ -194,7 +195,7 @@ class JSON2EDCLineageFiles:
         return None
 
     def find_latest_ref_file(self, src_or_tgt):
-        search_for_files = self.output_directory + "20*--REF_-_data-sources-" + src_or_tgt + "*dataset.json"
+        search_for_files = self.output_directory + "/" + "20*--REF_-_data-sources-" + src_or_tgt + "*dataset.json"
         # print("Looking for REF files with search >%s<" % search_for_files)
         list_of_files = glob(search_for_files)
         if list_of_files is not None and len(list_of_files) > 0:
@@ -350,7 +351,7 @@ class JSON2EDCLineageFiles:
         return targets
 
     def write_lineage_entry(self, entry):
-        filename = self.output_directory + "lineage-" + self.start_time_formatted + ".csv"
+        filename = path.join(self.output_directory, "lineage-" + self.start_time_formatted + ".csv")
         if path.exists(filename):
             append_or_write = "a"
             write_header = False
@@ -366,7 +367,7 @@ class JSON2EDCLineageFiles:
 
     def register_result(self, file, result):
         print("Result for file >%s< is >%s<" % (file, result["code"]))
-        filename = self.output_directory + "results-" + self.start_time_formatted + "-" + __name__ + ".txt"
+        filename = path.join(self.output_directory, "results-" + self.start_time_formatted + "-" + __name__ + ".txt")
         if path.exists(filename):
             append_or_write = "a"
         else:
@@ -374,7 +375,7 @@ class JSON2EDCLineageFiles:
         with open(filename, append_or_write) as out:
             out.write(file + ": " + json.dumps(result) + "\n")
         if result["code"] != "OK":
-            filename = self.output_directory + "errors-" + self.start_time_formatted + "-" + __name__ + ".txt"
+            filename = path.join(self.output_directory, "errors-" + self.start_time_formatted + "-" + __name__ + ".txt")
             if path.exists(filename):
                 append_or_write = "a"
             else:
